@@ -61,6 +61,7 @@ export interface ICrowApiProps {
   // without anything required
   // but jsii does not allow for Omit type
   apiGatewayConfiguration?: apigateway.LambdaRestApiProps | any,
+  apiGatewayName?: string,
   lambdaConfigurations?: CrowLambdaConfigurations,
   methodConfigurations?: CrowMethodConfigurations,
 }
@@ -102,6 +103,7 @@ export class CrowApi extends Construct {
       createApiKey = false,
       logRetention = logs.RetentionDays.ONE_WEEK,
       apiGatewayConfiguration = {},
+      apiGatewayName = 'crow-api',
       lambdaConfigurations = {},
       methodConfigurations = {},
     } = props;
@@ -177,7 +179,7 @@ export class CrowApi extends Construct {
     });
 
     // The API Gateway itself
-    const gateway = new apigateway.LambdaRestApi(this, 'api-gateway', {
+    const gateway = new apigateway.LambdaRestApi(this, apiGatewayName, {
       handler: defaultLambda,
       proxy: false,
       deploy: true,
